<?php
namespace Quivers\Integration\Block\Adminhtml\Form;

use Quivers\Integration\Observer\ConfigObserver;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Quivers\Integration\LogTracking;
class Button extends \Magento\Config\Block\System\Config\Form\Field
{
    protected $_backendSession;
    protected $_catalogSession;
    protected $messageManager;

    public function __construct(\Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Backend\Model\Session $backendSession,   
        \Magento\Catalog\Model\Session $catalogSession,
        array $data = [])
    {
        $this->_backendSession = $backendSession;
        $this->_catalogSession = $catalogSession;
        $this->messageManager = $messageManager;
        parent::__construct($context);
    }
    const BUTTON_TEMPLATE = 'system/config/button/button.phtml';

     /**
     * Set template to itself
     *
     * @return $this
     */
    protected function _prepareLayout()
    {
        parent::_prepareLayout();
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE;
        $objectManager = \Magento\Framework\App\ObjectManager::getInstance();
        $customer_session=$objectManager->get('\Magento\Customer\Model\Session');
        $quiverslable = $this->_scopeConfig->getValue('quivers/parameters/quivers_status_label',$storeScope);
        if($quiverslable=="InActive"){
        if($customer_session->getSettingStatus()=="Active"){
        $customer_session->setSettingStatus("Active");
        }else{
            $customer_session->setSettingStatus($quiverslable);
        }
        }else{
            $customer_session->setSettingStatus($quiverslable);
        }
        if (!$this->getTemplate()) {
            $this->setTemplate(static::BUTTON_TEMPLATE);
        }
        return $this;
    }

    public function getCatalogSession() 
    {
        return $this->_catalogSession;
    }
    public function getBackendSession()
        {
            return $this->_backendSession;
        }
   
    /**
     * Render button
     *
     * @param  \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string
     */
    public function render(\Magento\Framework\Data\Form\Element\AbstractElement $element)
    {
        // Remove scope label
        $element->unsScope()->unsCanUseWebsiteValue()->unsCanUseDefaultValue();
        return parent::render($element);
    }
    /**
     * Return ajax url for button
     *
     * @return string
     */
    public function getAjaxCheckUrl()
    {
        return $this->getUrl('addbutton/listdata'); //hit controller by ajax call on button click.
    }
    /**
     * Return ajax url for button
     *
     * @return string
     */
    public function getStatusCode($code=200)
    {   
        return $code; //hit controller by ajax call on button click.
    }
     /**
     * Get the button and scripts contents
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string
     */
    protected function _getElementHtml(\Magento\Framework\Data\Form\Element\AbstractElement $element)
    {   
        $objectManager = \Magento\Framework\App\ObjectManager::getInstance();
        $customer_session=$objectManager->get('\Magento\Customer\Model\Session');
        if ($customer_session->getSettingStatus()!="Active"){
            $this->messageManager->addErrorMessage("Failed to connect to Quivers. Please check if the settings in the Quivers and Quivers Tax tabs are saved correctly. If the issue still persists, please contact enterprise@quivers.com for further assistance.");
        }
        return $this->_toHtml();
    }
}